@@ -1,13 +1,16 @@
 # -*- coding: utf-8 -*-
 __all__ = ['MeCab', 'DictionaryInfo', 'MeCabNode', 'MeCabError']
 
-from .api import MeCab, DictionaryInfo, MeCabNode, MeCabError
+from .api import MeCabError
+from .dictionary import DictionaryInfo
+from .mecab import MeCab
+from .node import MeCabNode
 
-__version__ = '0.0.2'
-__version_info__ = (0, 0, 2)
+__version__ = '0.0.3'
+__version_info__ = (0, 0, 3)
 
 
-"""
+'''
 Copyright (c) 2014, Brooke M. Fujita.
 All rights reserved.
 
@@ -33,4 +36,4 @@ LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-"""
+'''
